@@ -1,4 +1,4 @@
-import os
+import socket
 from typing import Any
 
 from fastapi import FastAPI
@@ -9,10 +9,10 @@ def add_prometheus_middleware(
 ) -> None:
     from starlette_exporter import PrometheusMiddleware, handle_metrics
 
-    kwargs.setdefault("app", app.title.lower().replace(" ", "_"))
+    kwargs.setdefault("app_name", app.title.lower().replace(" ", "_"))
     kwargs.setdefault("skip_paths", ["/healthz", "/docs", "/openapi.json", "/metrics"])
     kwargs.setdefault("group_paths", True)
-    kwargs.setdefault("labels", {"server": os.getenv("HOSTNAME")})
+    kwargs.setdefault("labels", {"server": socket.gethostname()})
     kwargs.setdefault("always_use_int_status", True)
     app.add_middleware(PrometheusMiddleware, **kwargs)
     app.add_route(endpoint, handle_metrics)
