@@ -2,15 +2,17 @@ from typing import Any
 
 import orjson
 from fastapi.responses import JSONResponse
-from pydantic.json import pydantic_encoder
+from pydantic_core import to_jsonable_python
 
 
 class JsonResponse(JSONResponse):
-    media_type = "application/json"
-
     def render(self, content: Any) -> bytes:
+        if isinstance(content, bytes):
+            return content
+        if isinstance(content, str):
+            return content.encode("utf-8")
         return orjson.dumps(
             content,
             option=orjson.OPT_NON_STR_KEYS | orjson.OPT_SERIALIZE_NUMPY,
-            default=pydantic_encoder,
+            default=to_jsonable_python,
         )
